use rodio::{Decoder, Source};
use std::error::Error;
use std::fs::File;
use std::io::BufReader;
use std::path::PathBuf;

#[derive(Debug, Clone)]
pub struct Alert {
    path: PathBuf,
}

impl Alert {
    pub fn new(path: PathBuf) -> Self {
        Self { path }
    }

    pub fn load(&mut self, path: PathBuf) {
        self.path = path;
    }

    pub fn play(&self) -> Result<(), Box<dyn Error>> {
        let file = File::open(&self.path)?;
        let device = rodio::default_output_device().ok_or("No default output device found.")?;
        let source = Decoder::new(BufReader::new(file))?;

        rodio::play_raw(&device, source.convert_samples());
        Ok(())
    }
}
